==> haskell-glob-0.9.2-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-glob.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: Glob
version: 0.9.2
id: Glob-0.9.2-AbjvDlFSYnKBsiDSJQ0XCU
key: Glob-0.9.2-AbjvDlFSYnKBsiDSJQ0XCU
license: BSD-3-Clause
maintainer: Matti Niemenmaa <matti.niemenmaa+glob@iki.fi>
author: Matti Niemenmaa
stability: provisional
homepage: http://iki.fi/matti.niemenmaa/glob/
synopsis: Globbing library
description:
    A library for globbing: matching patterns against file paths.
category: System
abi: fe90daae121092f087f19649a03fe024
exposed: True
exposed-modules:
    System.FilePath.Glob System.FilePath.Glob.Primitive
hidden-modules: System.FilePath.Glob.Base
                System.FilePath.Glob.Directory System.FilePath.Glob.Match
                System.FilePath.Glob.Simplify System.FilePath.Glob.Utils
import-dirs: /usr/lib/ghc-8.4.3/site-local/Glob-0.9.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/Glob-0.9.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/Glob-0.9.2
hs-libraries: HSGlob-0.9.2-AbjvDlFSYnKBsiDSJQ0XCU
depends:
    base-4.11.1.0 containers-0.5.11.0 directory-1.3.1.5
    dlist-0.8.0.4-CrGJIvQnsM82JxkEwejrYD filepath-1.4.2
    transformers-0.5.5.0
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             dlist-0.8.0.4-CrGJIvQnsM82JxkEwejrYD=d8185cdeb1f72c3606ef0c9fb78dc6d0
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=197a030c492741542d6f49bc76370bb8
haddock-interfaces: /usr/share/doc/haskell-glob/html/Glob.haddock
haddock-html: /usr/share/doc/haskell-glob/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-glob-0.9.2-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-glob.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: Glob
version: 0.9.2
id: Glob-0.9.2-JA2Wi2KXENiYNgffORojv
key: Glob-0.9.2-JA2Wi2KXENiYNgffORojv
license: BSD-3-Clause
maintainer: Matti Niemenmaa <matti.niemenmaa+glob@iki.fi>
author: Matti Niemenmaa
stability: provisional
homepage: http://iki.fi/matti.niemenmaa/glob/
synopsis: Globbing library
description:
    A library for globbing: matching patterns against file paths.
category: System
abi: 93f1d1e308ff663fbeb6d0f1acab0c7a
exposed: True
exposed-modules:
    System.FilePath.Glob System.FilePath.Glob.Primitive
hidden-modules: System.FilePath.Glob.Base
                System.FilePath.Glob.Directory System.FilePath.Glob.Match
                System.FilePath.Glob.Simplify System.FilePath.Glob.Utils
import-dirs: /usr/lib/ghc-8.4.3/site-local/Glob-0.9.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/Glob-0.9.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/Glob-0.9.2
hs-libraries: HSGlob-0.9.2-JA2Wi2KXENiYNgffORojv
depends:
    base-4.11.1.0 containers-0.5.11.0 directory-1.3.1.5
    dlist-0.8.0.5-6LWFCfMSEKNIqqazR8mrr6 filepath-1.4.2
    transformers-0.5.5.0
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             dlist-0.8.0.5-6LWFCfMSEKNIqqazR8mrr6=a89500558697401c3bf5eb58146baa5c
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=197a030c492741542d6f49bc76370bb8
haddock-interfaces: /usr/share/doc/haskell-glob/html/Glob.haddock
haddock-html: /usr/share/doc/haskell-glob/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
